guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

05/16: gnu: vc: Use G-expressions.


From: guix-commits
Subject: 05/16: gnu: vc: Use G-expressions.
Date: Wed, 19 Jul 2023 16:06:14 -0400 (EDT)

nckx pushed a commit to branch master
in repository guix.

commit 24d4e8182d0cb783d39240e0af4ee5dbf999593f
Author: Tobias Geerinckx-Rice <me@tobias.gr>
AuthorDate: Sun Jul 16 02:00:01 2023 +0200

    gnu: vc: Use G-expressions.
    
    * gnu/packages/maths.scm (vc)[arguments]:
    Rewrite as G-expressions.
---
 gnu/packages/maths.scm | 25 +++++++++++++------------
 1 file changed, 13 insertions(+), 12 deletions(-)

diff --git a/gnu/packages/maths.scm b/gnu/packages/maths.scm
index 12d802268e..8c30e49d8f 100644
--- a/gnu/packages/maths.scm
+++ b/gnu/packages/maths.scm
@@ -5942,18 +5942,19 @@ supports compressed MAT files, as well as newer 
(version 7.3) MAT files.")
         (base32 "0zq37r8yisd4dwlb024l10wk2yq9kisa4xm79ia1ggrz7w2s13lq"))))
     (build-system cmake-build-system)
     (arguments
-     '(#:configure-flags
-       '("-DBUILD_TESTING=ON"
-         ;; By default, Vc will optimize for the CPU of the build machine.
-         ;; Setting this to "none" makes it create portable binaries.  See
-         ;; "cmake/OptimizeForArchitecture.cmake".
-         "-DTARGET_ARCHITECTURE=none")
-       #:phases (modify-phases %standard-phases
-                  (add-after 'unpack 'copy-testdata
-                    (lambda* (#:key inputs native-inputs #:allow-other-keys)
-                      (let ((testdata (assoc-ref (or native-inputs inputs)
-                                                 "testdata")))
-                        (copy-recursively testdata "tests/testdata")))))))
+     (list
+      #:configure-flags
+      #~(list "-DBUILD_TESTING=ON"
+              ;; By default, Vc will optimize for the CPU of the build machine.
+              ;; Setting this to "none" makes it create portable binaries.  See
+              ;; "cmake/OptimizeForArchitecture.cmake".
+              "-DTARGET_ARCHITECTURE=none")
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'copy-testdata
+            (lambda _
+              (copy-recursively #$(this-package-native-input "testdata")
+                                "tests/testdata"))))))
     (native-inputs
      `(("virtest" ,virtest)
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]